@@ -3,6 +3,7 @@ import enum as _enum
 import typing as _typing
 import datetime as _datetime
 import re as _re
+import distutils.util as _distutils_util
 from google.cloud import bigquery as _bigquery
 from google.cloud import storage as _storage
 from google.oauth2 import service_account as _service_account
@@ -43,8 +44,10 @@ class Options(object):
         self.labels = labels
 
         if correlation_id:
-            if not _re.match(r'[a-z]+', correlation_id):
-                raise ValueError('Correlation id must be sequence of lower case characters!')
+            if not _re.match(r"[a-z]+", correlation_id):
+                raise ValueError(
+                    "Correlation id must be sequence of lower case characters!"
+                )
 
         self.correlation_id = correlation_id
         self.now = now
@@ -104,7 +107,7 @@ class Options(object):
             bq_location=bq_location or self.bq_location,
             correlation_id=correlation_id or self.correlation_id,
             now=now or self.now,
-            labels=labels,
+            labels=labels or self.labels,
         )
 
 
@@ -184,6 +187,11 @@ class SchemaField(object):
         self.fields = fields
         self.mode = mode or FieldMode.NULLABLE
 
+    def __str__(self):
+        return "<Field:{name} {type} {mode}>".format(
+            name=self.name, type=self.field_type.name, mode=self.mode.name
+        )
+
     def to_bq_field(self):
         """
         Creates a SchemaField compatible with bigquery's python library
@@ -365,9 +373,16 @@ class SchemaField(object):
         if isinstance(value, int) and self.field_type == FieldType.BOOLEAN:
             value = value != 0
 
+        if isinstance(value, str) and self.field_type == FieldType.BOOLEAN:
+            value = _distutils_util.strtobool(value)
+
         if isinstance(value, _datetime.datetime) and self.field_type == FieldType.DATE:
             value = value.date()
 
+        if isinstance(value, str) and self.field_type == FieldType.DATE:
+            match = _re.match(r'(\d{4})-(\d\d)-(\d\d)', value)
+            value = _datetime.date(int(match.group(1)), int(match.group(2)), int(match.group(3)))
+
         if (
             not isinstance(value, str)
             and value is not None
@@ -422,12 +437,13 @@ class SchemaField(object):
         )
 
 
-def create_view(name: str, query: str, options: Options):
+def create_view(name: str, query: str, options: Options, description: str = None):
     """
     Create a view inside bigquery
 
     :param name: The name of the view (corresponds to a table id)
-    :param query: The SQL query that specifies the content of the vieww
+    :param description: Description text of the view
+    :param query: The SQL query that specifies the content of the view
     :param options: The access config object that defines project_id and other common parameters
     """
     bigquery = options.get_bigquery_client()
@@ -435,7 +451,22 @@ def create_view(name: str, query: str, options: Options):
 
     view = _bigquery.Table(view_ref)
     view.view_query = query
-    return bigquery.create_table(view, exists_ok=True)
+    table = bigquery.create_table(view, exists_ok=True)
+    if table.view_query != query:
+        table.view_query = query
+        table = bigquery.update_table(table=table, fields=["view_query"])
+
+    if options.labels:
+        table = check_and_update_labels(
+            table=table, labels=options.labels, bigquery=bigquery
+        )
+
+    if description:
+        table = check_and_update_description(
+            table=table, table_description=description, bigquery=bigquery
+        )
+
+    return table
 
 
 def check_and_update_labels(table, labels, bigquery):
@@ -470,7 +501,9 @@ def check_and_update_external_config(table, external_config, bigquery):
     """
     if table.external_data_configuration != external_config:
         table.external_data_configuration = external_config
-        return bigquery.update_table(table=table, fields=["external_data_configuration"])
+        return bigquery.update_table(
+            table=table, fields=["external_data_configuration"]
+        )
     return table
 
 
@@ -483,9 +516,7 @@ def check_and_update_schema(table, schema, bigquery, auto_update_table_schema=Tr
     if not schema:
         return table
 
-    bq_schema = (
-        None if schema is None else [f.to_bq_field() for f in schema]
-    )
+    bq_schema = None if schema is None else [f.to_bq_field() for f in schema]
 
     def extract_schema_fields(schema):
         if not schema:
@@ -513,9 +544,7 @@ def check_and_update_schema(table, schema, bigquery, auto_update_table_schema=Tr
             bigquery.update_table(table=table, fields=["schema"])
             return table
         else:
-            raise ValueError(
-                "Schema not up-to-date"
-            )
+            raise ValueError("Schema not up-to-date")
 
     return table
 
